@@ -3,14 +3,13 @@ if defined?(Merb)
   require "haml"
   require "merb-haml/template"
   Merb::Plugins.add_rakefiles(File.join(File.dirname(__FILE__) / "merb-haml" / "merbtasks"))
-
-  Merb::Plugins.config[:haml] ||= {}
+  
   Merb::Plugins.config[:sass] ||= {}
 
   Merb::BootLoader.after_app_loads do
     
     if File.directory?(Merb::Plugins.config[:sass][:template_location] || Merb.dir_for(:stylesheet) / "sass")
-      require "sass/plugin" 
+      require "sass"
       if Merb::Config[:sass]
         Merb.logger.info("Please define your sass settings in Merb::Plugins.config[:sass] not Merb::Config")
         Sass::Plugin.options = Merb::Config[:sass]
